Multiscale Structural Similarity Index (MSSSIM)
===============================================

.. automodule:: viqa.fr_metrics.msssim
    :exclude-members: MSSSIM

   
.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.msssim

.. autosummary::
    :toctree: generated/
    :template: class.rst

    MSSSIM